@@ -66,7 +66,7 @@ from robot.libraries.BuiltIn import BuiltIn
 from robot.running.namespace import IMPORTER
 from robot.variables import is_var
 
-__version__ = '1.0.0'
+__version__ = '1.0.2'
 
 HISTORY_PATH = os.environ.get('RFDEBUG_HISTORY', '~/.rfdebug_history')
 KEYWORD_SEP = re.compile('  +|\t')
@@ -174,6 +174,7 @@ def get_keywords():
         for keyword in get_lib_keywords(lib.name):
             yield keyword
 
+
 NORMAL_STYLE = style_from_dict({
     Token.Head: '#00FF00',
     Token.Message: '#CCCCCC',
@@ -396,7 +397,8 @@ class DebugCmd(PtkCmd):
             print('''\
 Input Robotframework keywords, or commands listed below.
 Use "libs" or "l" to see available libraries,
-use "keywords" or "k" see list of library keywords.\
+use "keywords" or "k" see list of library keywords,
+use the TAB keyboard key to auto complete keywords.\
 ''')
 
         PtkCmd.do_help(self, arg)
@@ -421,12 +423,12 @@ use "keywords" or "k" see list of library keywords.\
             name = keyword['lib'] + '.' + keyword['name']
             commands.append((name,
                              keyword['name'],
-                             'Keyword: {0}'.format(keyword['doc'])))
+                             u'Keyword: {0}'.format(keyword['doc'])))
             # name without library
             commands.append((keyword['name'],
                              keyword['name'],
-                             'Keyword[{0}.]: {1}'.format(keyword['lib'],
-                                                         keyword['doc'])))
+                             u'Keyword[{0}.]: {1}'.format(keyword['lib'],
+                                                          keyword['doc'])))
 
         cmd_completer = CmdCompleter(commands, self)
         return cmd_completer
